summaryrefslogtreecommitdiffstats
path: root/docker
diff options
context:
space:
mode:
authorPeter Mikus <pmikus@cisco.com>2021-08-24 09:13:14 +0000
committerGerrit Code Review <gerrit@fd.io>2021-08-24 09:13:14 +0000
commit1f0bc2a84a59c3038804f27e48f7bdc9f5069787 (patch)
tree1b68013ff4847aba24ea0c5d1e09141abbc10743 /docker
parentd666c53998a7fafc94feeb75139490cf9332a560 (diff)
parenteb9d5ee86b4a3eb5ea8b687deeef2f6640365106 (diff)
Merge "Add terraform to docker CI executor images."
Diffstat (limited to 'docker')
-rwxr-xr-xdocker/scripts/dbld_vpp_install_packages.sh4
-rw-r--r--docker/scripts/lib_apt.sh12
2 files changed, 12 insertions, 4 deletions
diff --git a/docker/scripts/lib_apt.sh b/docker/scripts/lib_apt.sh
index 69c2d27c..86b7c3fc 100644
--- a/docker/scripts/lib_apt.sh
+++ b/docker/scripts/lib_apt.sh
@@ -54,8 +54,8 @@ apt_override_cmake_install_with_pip3_version() {
generate_apt_dockerfile_common() {
local executor_class="$1"
local executor_image="$2"
- debian_docker_inst_sed="| sed -e 's/has_rootless_extras="1"//g' | sh
-"
+ local dpkg_arch="$(dpkg --print-architecture)"
+
cat <<EOF >>"$DOCKERFILE"
# Create download dir to cache external tarballs
@@ -196,6 +196,7 @@ RUN apt-get update -qq \\
zlib1g-dev \\
&& curl -L https://packagecloud.io/fdio/master/gpgkey | apt-key add - \\
&& curl -s https://packagecloud.io/install/repositories/fdio/master/script.deb.sh | bash \\
+
EOF
# Docker installation script fails on debian-9, so don't install docker
head $DOCKERFILE
@@ -206,6 +207,13 @@ EOF
cat <<EOF >>"$DOCKERFILE"
&& rm -r /var/lib/apt/lists/*
+# Install terraform for CSIT
+#
+RUN wget https://releases.hashicorp.com/terraform/1.0.4/terraform_1.0.4_linux_$dpkg_arch.zip \\
+ && unzip terraform_1.0.4_linux_$dpkg_arch.zip \\
+ && mv terraform /usr/bin \\
+ && rm -f terraform_1.0.4_linux_$dpkg_arch.zip
+
# Install packages for all project branches
#
RUN apt-get update -qq \\
diff --git a/docker/scripts/dbld_vpp_install_packages.sh b/docker/scripts/dbld_vpp_install_packages.sh
index 707096b4..99d49084 100755
--- a/docker/scripts/dbld_vpp_install_packages.sh
+++ b/docker/scripts/dbld_vpp_install_packages.sh
@@ -38,8 +38,8 @@ for branch in ${VPP_BRANCHES[$OS_NAME]} ; do
# Install OS packages
make_vpp "install-dep" "$branch"
make_vpp "centos-pyyaml" "$branch" # VPP Makefile tests for centos versions
- if [ "$OS_ID" = "ubuntu" ] ; then
- # 'Make docs jobs are only run on ubuntu executors
+ if [ "$OS_ID" = "ubuntu" ] && [ "$OS_ARCH" = "x86_64" ] ; then
+ # 'Make docs jobs are only run on ubuntu x86_64 executors
# so only run for ubuntu build executors.
make_vpp "docs-venv" "$branch"
elif [ "$OS_NAME" = "debian-9" ] ; then